Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/robotml/org.eclipse.papyrus.robotml/src/org/eclipse/papyrus/RobotML/Software.java')
-rw-r--r--extraplugins/robotml/org.eclipse.papyrus.robotml/src/org/eclipse/papyrus/RobotML/Software.java35
1 files changed, 18 insertions, 17 deletions
diff --git a/extraplugins/robotml/org.eclipse.papyrus.robotml/src/org/eclipse/papyrus/RobotML/Software.java b/extraplugins/robotml/org.eclipse.papyrus.robotml/src/org/eclipse/papyrus/RobotML/Software.java
index 3a07bae05f5..c925b5046ab 100644
--- a/extraplugins/robotml/org.eclipse.papyrus.robotml/src/org/eclipse/papyrus/RobotML/Software.java
+++ b/extraplugins/robotml/org.eclipse.papyrus.robotml/src/org/eclipse/papyrus/RobotML/Software.java
@@ -11,7 +11,7 @@ package org.eclipse.papyrus.RobotML;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.papyrus.RobotML.Software#isIsPeriodic <em>Is Periodic</em>}</li>
+ * <li>{@link org.eclipse.papyrus.RobotML.Software#isPeriodic <em>Is Periodic</em>}</li>
* <li>{@link org.eclipse.papyrus.RobotML.Software#getPeriod <em>Period</em>}</li>
* <li>{@link org.eclipse.papyrus.RobotML.Software#getPriority <em>Priority</em>}</li>
* <li>{@link org.eclipse.papyrus.RobotML.Software#getDeadline <em>Deadline</em>}</li>
@@ -28,7 +28,8 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* Returns the value of the '<em><b>Is Periodic</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Is Periodic</em>' attribute isn't clear, there really should be more of a description here...
+ * If the meaning of the '<em>Is Periodic</em>' attribute isn't clear,
+ * there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Is Periodic</em>' attribute.
@@ -37,14 +38,14 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* @model dataType="org.eclipse.uml2.types.Boolean" required="true" ordered="false"
* @generated
*/
- boolean isIsPeriodic();
+ boolean isPeriodic();
/**
* Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#isIsPeriodic <em>Is Periodic</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Is Periodic</em>' attribute.
- * @see #isIsPeriodic()
+ * @see #isPeriodic()
* @generated
*/
void setIsPeriodic(boolean value);
@@ -57,12 +58,12 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Period</em>' attribute.
- * @see #setPeriod(float)
+ * @see #setPeriod(Float32)
* @see org.eclipse.papyrus.RobotML.RobotMLPackage#getSoftware_Period()
* @model dataType="org.eclipse.papyrus.RobotMLLibraries.RobotML_ModelLibrary.RobotML_DataTypes.std_datatypes.Float32" required="true" ordered="false"
* @generated
*/
- float getPeriod();
+ Object getPeriod();
/**
* Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#getPeriod <em>Period</em>}' attribute.
@@ -72,7 +73,7 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* @see #getPeriod()
* @generated
*/
- void setPeriod(float value);
+ void setPeriod(Object value);
/**
* Returns the value of the '<em><b>Priority</b></em>' attribute.
@@ -82,12 +83,12 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Priority</em>' attribute.
- * @see #setPriority(char)
+ * @see #setPriority(UInt8)
* @see org.eclipse.papyrus.RobotML.RobotMLPackage#getSoftware_Priority()
* @model dataType="org.eclipse.papyrus.RobotMLLibraries.RobotML_ModelLibrary.RobotML_DataTypes.std_datatypes.UInt8" required="true" ordered="false"
* @generated
*/
- char getPriority();
+ Object getPriority();
/**
* Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#getPriority <em>Priority</em>}' attribute.
@@ -97,7 +98,7 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* @see #getPriority()
* @generated
*/
- void setPriority(char value);
+ void setPriority(Object value);
/**
* Returns the value of the '<em><b>Deadline</b></em>' attribute.
@@ -107,12 +108,12 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Deadline</em>' attribute.
- * @see #setDeadline(float)
+ * @see #setDeadline(Float32)
* @see org.eclipse.papyrus.RobotML.RobotMLPackage#getSoftware_Deadline()
* @model dataType="org.eclipse.papyrus.RobotMLLibraries.RobotML_ModelLibrary.RobotML_DataTypes.std_datatypes.Float32" required="true" ordered="false"
* @generated
*/
- float getDeadline();
+ Object getDeadline();
/**
* Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#getDeadline <em>Deadline</em>}' attribute.
@@ -122,7 +123,7 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* @see #getDeadline()
* @generated
*/
- void setDeadline(float value);
+ void setDeadline(Object value);
/**
* Returns the value of the '<em><b>Wcet</b></em>' attribute.
@@ -132,12 +133,12 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Wcet</em>' attribute.
- * @see #setWcet(float)
+ * @see #setWcet(Float32)
* @see org.eclipse.papyrus.RobotML.RobotMLPackage#getSoftware_Wcet()
* @model dataType="org.eclipse.papyrus.RobotMLLibraries.RobotML_ModelLibrary.RobotML_DataTypes.std_datatypes.Float32" required="true" ordered="false"
* @generated
*/
- float getWcet();
+ Object getWcet();
/**
* Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#getWcet <em>Wcet</em>}' attribute.
@@ -147,6 +148,6 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
* @see #getWcet()
* @generated
*/
- void setWcet(float value);
+ void setWcet(Object value);
} // Software

Back to the top
@@ -37,14 +38,14 @@ public interface Software extends org.eclipse.papyrus.RobotML.System {
/**
- * Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#isIsPeriodic <em>Is Periodic</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.RobotML.Software#isPeriodic <em>Is Periodic</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->